pub trait ConsensusScope:
Clone
+ Eq
+ Hash
+ Send
+ Sync
+ Debug
+ 'static { }Expand description
A scope groups related proposals together.
Think of it like a namespace or category. For example, you might use a scope as group of users. Any type that can be used as a group of users can be used as a scope.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.